@@ -1,8 +1,9 @@
 use dbfile::DBStore;
 use dbfile_derive::DBfile;
+use lazy_static::__Deref;
 use requests2::{Cache, Headers, Requests, Store, Value};
 use select::predicate::{Class, Name};
-use std::{collections::HashMap};
+use std::{collections::HashMap, rc::Rc, thread, time::Duration};
 
 pub fn run_selector() {
     // .class .class.class #[attr=value] #id
@@ -156,7 +157,7 @@ pub fn run_free_parse_and_store_to_csv() {
                 .iter()
                 .map(|x| Link {
                     title: &title,
-                    href: x.attr("href").unwrap_or_default(),
+                    href: x.attr("href").expect("extra href error"),
                     link_name: x.text(),
                 })
                 .collect::<Vec<Link>>();
@@ -166,3 +167,77 @@ pub fn run_free_parse_and_store_to_csv() {
     });
 }
 
+pub fn crawl_kongfz() {
+    let mut urls = Vec::new();
+
+    for p in 200..201 {
+        let mut _hash = HashMap::new();
+        _hash.insert("url", format!("https://book.kongfz.com/Cxianzhuang/cat_8001w{}/", p));
+        _hash.insert("page", format!("{}", p));
+        urls.push(_hash);
+    }
+
+    for url in urls {
+        let p:i32 = url.get("page").unwrap().parse().unwrap();
+        crawl_kongfz_by_page(p, url.get("url").unwrap().to_string());
+        thread::sleep(Duration::from_millis(2000));
+    }
+}
+
+pub fn crawl_kongfz_by_page(page: i32, url: String) {
+    let data = Cache::new();
+    let client = Requests::new(&data);
+    let rq = client.connect(&url, Headers::Default);
+
+    #[derive(DBfile, Debug)]
+    struct Item<'a> {
+        book_name: &'a str,
+        price: f32,
+        href: &'a str,
+        img:&'a str,
+        isbn:&'a str,
+    }
+
+    rq.free_parse(|mut p| {
+        p.free_select(".item.clearfix", |nodes| {
+            let book_item = nodes
+                .iter()
+                .enumerate()
+                .filter(|(_idx, n)| n.attr("itemname").is_some())
+                .map(|(idx, x)| {
+
+                    let book_name = Rc::new(x.attr("itemname").unwrap().to_string());
+                    let isbn = Rc::new(x.attr("isbn").unwrap().to_string());
+                    let price:f32 = Rc::new(x.attr("price").unwrap()).parse().unwrap();
+                    let href = Rc::new(x.find(Name("a")).find_map(|n| n.attr("href")).unwrap().to_string());
+                    let img = Rc::new(x.find(Name("img")).find_map(|n| n.attr("src")).unwrap().to_string());
+                    
+                    
+                    let mut header = false;
+                    if idx == 0 && page == 1 { header = true };
+                    DBStore::to_csv(vec![
+                        Item { 
+                            book_name: Rc::clone(&book_name).deref(),
+                            price,
+                            href: Rc::clone(&href).deref(),
+                            img: Rc::clone(&img).deref(),
+                            isbn: Rc::clone(&isbn).deref(),
+                        }
+                    ], "links2.csv", "a", header);
+
+                    let hash = HashMap::from([
+                        ("book_name".to_string(), Rc::clone(&book_name)),
+                        ("href".to_string(), Rc::clone(&href)),
+                        ("isbn".to_string(), Rc::clone(&isbn)),
+                        // ("price".to_string(), Rc::new(price.to_string())),
+                        ("img".to_string(), Rc::clone(&img))
+                        ]);
+                    // }
+                    hash
+                })
+                .collect::<Vec<HashMap<String, Rc<String>>>>();
+
+            print!("{:?}", book_item)
+        });
+    })
+}
