@@ -31,5 +31,6 @@ fn test_headers_json() {
 
 #[test]
 fn test_free_parse_and_store_to_csv() {
-    css_selector::run_free_parse_and_store_to_csv();
+    // css_selector::run_free_parse_and_store_to_csv();
+    css_selector::crawl_kongfz();
 }
\ No newline at end of file
